# allen-powerplatform-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 0.1.1
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import allen_powerplatform_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import allen_powerplatform_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import allen_powerplatform_client
from allen_powerplatform_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://8fd02505cbdee9558087f7d04a48a5.11.environment.api.powerplatform.com
# See configuration.py for a list of all supported configuration parameters.
configuration = allen_powerplatform_client.Configuration(
    host = "https://8fd02505cbdee9558087f7d04a48a5.11.environment.api.powerplatform.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]

configuration.access_token = os.environ["ACCESS_TOKEN"]

configuration.access_token = os.environ["ACCESS_TOKEN"]


# Enter a context with an instance of the API client
with allen_powerplatform_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = allen_powerplatform_client.DefaultApi(api_client)
    api_version = 1 # int |  (default to 1)

    try:
        # Get Table Names Power Automate Flow
        api_response = api_instance.fetch_table_names(api_version)
        print("The response of DefaultApi->fetch_table_names:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->fetch_table_names: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://8fd02505cbdee9558087f7d04a48a5.11.environment.api.powerplatform.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**fetch_table_names**](docs/DefaultApi.md#fetch_table_names) | **POST** /powerautomate/automations/direct/workflows/70452d9b21584637a8023e3d66fc37ea/triggers/manual/paths/invoke | Get Table Names Power Automate Flow
*DefaultApi* | [**get_table**](docs/DefaultApi.md#get_table) | **POST** /powerautomate/automations/direct/workflows/0438716ee92b4378811dbc975401decd/triggers/manual/paths/invoke | Gets all data for a table by table name
*DefaultApi* | [**post_water_record**](docs/DefaultApi.md#post_water_record) | **POST** /powerautomate/automations/direct/workflows/6148df039f724a4da146cc793585b8d2/triggers/manual/paths/invoke | Posts a water record from WaterLog into the dataverse weights water table
*DefaultApi* | [**post_weight_record**](docs/DefaultApi.md#post_weight_record) | **POST** /powerautomate/automations/direct/workflows/4be33b76ba3843058033eeb4d82b5240/triggers/manual/paths/invoke | Posts a weight record from water log


## Documentation For Models

 - [GetTableRequest](docs/GetTableRequest.md)
 - [PostWaterRecordRequest](docs/PostWaterRecordRequest.md)
 - [PostWeightRecordRequest](docs/PostWeightRecordRequest.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="oauth2-auth"></a>
### oauth2-auth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://login.microsoftonline.com/common/oauth2/authorize
- **Scopes**: 
 - **https://service.flow.microsoft.com//.default**: https://service.flow.microsoft.com//.default

<a id="oAuthClientCredentials"></a>
### oAuthClientCredentials

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **https://service.flow.microsoft.com//.default**: https://service.flow.microsoft.com//.default

<a id="certOauth"></a>
### certOauth

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **https://service.flow.microsoft.com//.default**: https://service.flow.microsoft.com//.default


## Author




